import * as i0 from '@angular/core';
import { EventEmitter, Component, Input, Output, NgModule, NO_ERRORS_SCHEMA } from '@angular/core';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';

class SDKSelectComponent {
    constructor() {
        this.labelPosition = "left"; // Text located to the 'left' or 'top' position of dropdown.
        this.noValueLabel = "..."; // 'No Value' label.
        this.noValueDisabled = true; // Prevent 'No Value' from being selected.
        this.multiSelect = false; // Indicates single or multiple selections.
        this.multiValues = true; // Show multiple values in the dropdown display or 'n selected' message after 2+ values selected.
        this.selectChangeEvent = new EventEmitter(); // Event triggered on selections.
        this.showDropdown = false;
    }
    ngOnInit() {
        if (!this.multiSelect && this.selectedOptions) {
            let tmp = [];
            tmp.push(this.selectedOptions);
            this.selectedOptions = tmp;
        }
        setTimeout(() => {
            this.setStyle();
        }, 1);
    }
    valueBuilder(option) {
        let re = /\[([^\]]+)\]/g;
        let x = this.displayValue.match(re);
        let value = this.displayValue;
        if (x) {
            x.forEach((segment) => {
                let z = option[segment.replace("[", "").replace("]", "")];
                value = value.replaceAll(segment, z);
            });
        }
        else {
            value = option[value];
        }
        return value;
    }
    selectionBuilder() {
        let selection = "";
        if (this.multiSelect) {
            if (this.multiValues) {
                if (this.displayValue && this.displayValue !== "") {
                    let tmp = [];
                    this.selectedOptions.forEach((item) => {
                        tmp.push(this.valueBuilder(item));
                    });
                    selection = tmp.join(", ");
                }
                else {
                    selection = this.selectedOptions;
                }
            }
            else {
                if (this.selectedOptions.length === 1) {
                    selection = this.valueBuilder(this.selectedOptions[0]);
                }
                else {
                    selection = this.selectedOptions.length + ' selected';
                }
            }
        }
        else {
            selection = this.valueBuilder(this.selectedOptions[0]);
        }
        return selection;
    }
    titleBuilder() {
        let title = "";
        let tmp = [];
        if (this.selectedOptions && this.selectedOptions.length > 0) {
            this.selectedOptions.forEach((item) => {
                if (this.displayValue && this.displayValue !== "") {
                    tmp.push(this.valueBuilder(item));
                }
                else {
                    tmp.push(item);
                }
            });
            title = `Selected value(s):\n${tmp.join("\n")}`;
        }
        return title;
    }
    isSelected(option) {
        let ndx = (this.selectedOptions && this.selectedOptions !== "") ? this.selectedOptions?.findIndex((item) => JSON.stringify(item) === JSON.stringify(option)) : -1;
        return (ndx > -1) ? true : false;
    }
    selectItem(option) {
        let ndx = (this.selectedOptions && this.selectedOptions !== "") ? this.selectedOptions?.findIndex((item) => JSON.stringify(item) === JSON.stringify(option)) : -1;
        if (ndx > -1) {
            if (this.multiSelect || !this.noValueDisabled) {
                this.selectedOptions.splice(ndx, 1);
            }
        }
        else {
            if (!this.multiSelect || !this.selectedOptions) {
                this.selectedOptions = [];
            }
            this.selectedOptions.push(option);
        }
        if (!this.multiSelect && this.noValueDisabled) {
            this.showDropdown = false;
        }
        this.selectChangeEvent.emit(this.selectedOptions);
    }
    setStyle() {
        let element = document.getElementById("select");
        if (element) {
            element.style.setProperty("--hover-color", this.hoverColor);
            element.style.setProperty("--selected-color", this.selectedColor);
            element.style.setProperty("--selected-background", this.selectedBackground);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.8", ngImport: i0, type: SDKSelectComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.1.8", type: SDKSelectComponent, selector: "sdk-select", inputs: { label: "label", labelPosition: "labelPosition", labelStyle: "labelStyle", options: "options", optionStyle: "optionStyle", noValueLabel: "noValueLabel", noValueDisabled: "noValueDisabled", displayValue: "displayValue", multiSelect: "multiSelect", multiValues: "multiValues", selectedOptions: "selectedOptions", hoverColor: "hoverColor", selectedColor: "selectedColor", selectedBackground: "selectedBackground" }, outputs: { selectChangeEvent: "selectChangeEvent" }, ngImport: i0, template: "<div class=\"sdk-select\" [ngStyle]=\"{ display: (labelPosition === 'top') ? 'unset' : 'flex' }\">\n    <div *ngIf=\"label\" class=\"label\" [style]=\"labelStyle\">{{ label }}</div>\n\n    <!-- Single Selection -->\n    <div *ngIf=\"!multiSelect\" class=\"box\" [style]=\"optionStyle\" (mouseleave)=\"showDropdown = false\">\n        <div class=\"selectbox\" [title]=\"titleBuilder()\">\n            <div class=\"dropdown\" (click)=\"showDropdown=!showDropdown\">\n                <div class=\"value\" *ngIf=\"!selectedOptions || selectedOptions.length === 0\">{{ noValueLabel }}</div>\n                <div class=\"value\" *ngIf=\"selectedOptions && selectedOptions.length > 0\">{{ (displayValue) ? selectionBuilder() : selectedOptions }}</div>\n                <div class=\"icon material-symbols-outlined\">expand_more</div>\n            </div>\n            <div class=\"values\" *ngIf=\"showDropdown\" [style]=\"optionStyle\">\n                <label *ngFor=\"let option of options\" (click)=\"selectItem(option)\" [ngClass]=\"{ selected : isSelected(option) }\" [title]=\"(displayValue) ? valueBuilder(option) : option\">\n                    <div class=\"value\">\n                        <div class=\"value-text\">{{ (displayValue) ? valueBuilder(option) : option }}</div>\n                        <div *ngIf=\"!noValueDisabled && isSelected(option)\" class=\"icon right material-symbols-outlined\">check</div>\n                    </div>\n                </label>\n            </div>\n        </div>\n    </div>\n\n    <!-- Multi Selection -->\n    <div *ngIf=\"multiSelect\" class=\"box\" [style]=\"optionStyle\" (mouseleave)=\"showDropdown = false\">\n        <div class=\"selectbox\" [title]=\"titleBuilder()\">\n            <div class=\"dropdown\" (click)=\"showDropdown=!showDropdown\">\n                <div class=\"value\" *ngIf=\"!selectedOptions || selectedOptions.length === 0\">{{ noValueLabel }}</div>\n                <div class=\"value\" *ngIf=\"selectedOptions && selectedOptions.length > 0\">{{ selectionBuilder() }}</div>\n                <div class=\"icon material-symbols-outlined\">expand_more</div>\n            </div>\n            <div class=\"values\" *ngIf=\"showDropdown\" [style]=\"optionStyle\">\n                <label *ngFor=\"let option of options\" (click)=\"selectItem(option)\" [ngClass]=\"{ selected : isSelected(option) }\" [title]=\"(displayValue) ? valueBuilder(option) : option\">\n                    <div class=\"icon left material-symbols-outlined\">{{ isSelected(option) ? 'check_box' : 'check_box_outline_blank' }}</div>\n                    <div class=\"value\">\n                        <div class=\"value-text\">{{ (displayValue) ? valueBuilder(option) : option }}</div>\n                    </div>\n                </label>\n            </div>\n        </div>\n    </div>\n</div>\n", styles: ["@import\"https://fonts.googleapis.com/css2?family=Material+Symbols+Outlined:opsz,wght,FILL,GRAD@20..48,100..700,0..1,-50..200\";.sdk-select{position:relative;display:flex;flex-direction:row;align-items:center;margin:0;padding:0;min-height:32px;min-width:50px;max-width:100%}.sdk-select .label{margin-right:10px}.sdk-select .box{position:relative;background-color:#fff;border:1px solid #BABABA;width:100%;min-height:inherit;min-width:inherit;max-width:inherit;margin:0;padding:0}.sdk-select .box .selectbox{position:relative;height:inherit;width:inherit;min-height:inherit;min-width:inherit;max-width:inherit;margin:0;padding:0;font-family:inherit;font-size:inherit}.sdk-select .box .selectbox *{cursor:pointer}.sdk-select .box .selectbox .dropdown{position:relative;background-color:transparent;border:none;height:inherit;width:inherit;min-height:inherit;min-width:inherit;max-width:inherit;margin:0;padding:0;font-family:inherit;font-size:inherit;text-align:left}.sdk-select .box .selectbox .dropdown .value{position:absolute;inset:40% 25px 0 5px;display:block;margin:0;padding:0;transform:translateY(-30%);font-family:inherit;font-size:inherit;text-overflow:ellipsis;overflow:hidden;white-space:nowrap}.sdk-select .box .selectbox .dropdown .icon{position:absolute;top:50%;right:0;bottom:0;display:flex;flex-direction:row;align-items:center;width:25px;min-width:25px;max-width:25px;transform:translateY(-50%)}.sdk-select .box .selectbox .values{position:absolute;left:0;right:0;width:inherit;min-width:inherit;max-width:inherit;height:unset!important;min-height:-moz-fit-content!important;min-height:fit-content!important;overflow:hidden;z-index:999;background-color:#fff;border:1px solid #BABABA;font-family:inherit;font-size:inherit}.sdk-select .box .selectbox .values *{cursor:pointer}.sdk-select .box .selectbox .values label{padding:5px 10px 5px 5px;display:block;min-width:inherit;max-width:inherit;white-space:nowrap;font-family:inherit;font-size:inherit}.sdk-select .box .selectbox .values label .icon{display:inline-flex;vertical-align:middle;font-size:1.3em}.sdk-select .box .selectbox .values label .icon.left{margin-right:10px}.sdk-select .box .selectbox .values label .icon.right{margin-left:10px}.sdk-select .box .selectbox .values label .value{position:relative;display:inline-flex;vertical-align:middle;font-family:inherit;font-size:inherit;width:inherit;min-width:inherit;max-width:inherit}.sdk-select .box .selectbox .values label .value .value-text{font-family:inherit;font-size:inherit;text-overflow:ellipsis;overflow:hidden;white-space:nowrap}.sdk-select .box .selectbox .values label.selected{color:var(--selected-color, rgb(25, 100, 141));background-color:var(--selected-background, rgb(225, 245, 255))}.sdk-select .box .selectbox .values label:hover{background-color:var(--hover-color, rgb(240, 240, 240))}\n"], dependencies: [{ kind: "directive", type: i1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.8", ngImport: i0, type: SDKSelectComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sdk-select', template: "<div class=\"sdk-select\" [ngStyle]=\"{ display: (labelPosition === 'top') ? 'unset' : 'flex' }\">\n    <div *ngIf=\"label\" class=\"label\" [style]=\"labelStyle\">{{ label }}</div>\n\n    <!-- Single Selection -->\n    <div *ngIf=\"!multiSelect\" class=\"box\" [style]=\"optionStyle\" (mouseleave)=\"showDropdown = false\">\n        <div class=\"selectbox\" [title]=\"titleBuilder()\">\n            <div class=\"dropdown\" (click)=\"showDropdown=!showDropdown\">\n                <div class=\"value\" *ngIf=\"!selectedOptions || selectedOptions.length === 0\">{{ noValueLabel }}</div>\n                <div class=\"value\" *ngIf=\"selectedOptions && selectedOptions.length > 0\">{{ (displayValue) ? selectionBuilder() : selectedOptions }}</div>\n                <div class=\"icon material-symbols-outlined\">expand_more</div>\n            </div>\n            <div class=\"values\" *ngIf=\"showDropdown\" [style]=\"optionStyle\">\n                <label *ngFor=\"let option of options\" (click)=\"selectItem(option)\" [ngClass]=\"{ selected : isSelected(option) }\" [title]=\"(displayValue) ? valueBuilder(option) : option\">\n                    <div class=\"value\">\n                        <div class=\"value-text\">{{ (displayValue) ? valueBuilder(option) : option }}</div>\n                        <div *ngIf=\"!noValueDisabled && isSelected(option)\" class=\"icon right material-symbols-outlined\">check</div>\n                    </div>\n                </label>\n            </div>\n        </div>\n    </div>\n\n    <!-- Multi Selection -->\n    <div *ngIf=\"multiSelect\" class=\"box\" [style]=\"optionStyle\" (mouseleave)=\"showDropdown = false\">\n        <div class=\"selectbox\" [title]=\"titleBuilder()\">\n            <div class=\"dropdown\" (click)=\"showDropdown=!showDropdown\">\n                <div class=\"value\" *ngIf=\"!selectedOptions || selectedOptions.length === 0\">{{ noValueLabel }}</div>\n                <div class=\"value\" *ngIf=\"selectedOptions && selectedOptions.length > 0\">{{ selectionBuilder() }}</div>\n                <div class=\"icon material-symbols-outlined\">expand_more</div>\n            </div>\n            <div class=\"values\" *ngIf=\"showDropdown\" [style]=\"optionStyle\">\n                <label *ngFor=\"let option of options\" (click)=\"selectItem(option)\" [ngClass]=\"{ selected : isSelected(option) }\" [title]=\"(displayValue) ? valueBuilder(option) : option\">\n                    <div class=\"icon left material-symbols-outlined\">{{ isSelected(option) ? 'check_box' : 'check_box_outline_blank' }}</div>\n                    <div class=\"value\">\n                        <div class=\"value-text\">{{ (displayValue) ? valueBuilder(option) : option }}</div>\n                    </div>\n                </label>\n            </div>\n        </div>\n    </div>\n</div>\n", styles: ["@import\"https://fonts.googleapis.com/css2?family=Material+Symbols+Outlined:opsz,wght,FILL,GRAD@20..48,100..700,0..1,-50..200\";.sdk-select{position:relative;display:flex;flex-direction:row;align-items:center;margin:0;padding:0;min-height:32px;min-width:50px;max-width:100%}.sdk-select .label{margin-right:10px}.sdk-select .box{position:relative;background-color:#fff;border:1px solid #BABABA;width:100%;min-height:inherit;min-width:inherit;max-width:inherit;margin:0;padding:0}.sdk-select .box .selectbox{position:relative;height:inherit;width:inherit;min-height:inherit;min-width:inherit;max-width:inherit;margin:0;padding:0;font-family:inherit;font-size:inherit}.sdk-select .box .selectbox *{cursor:pointer}.sdk-select .box .selectbox .dropdown{position:relative;background-color:transparent;border:none;height:inherit;width:inherit;min-height:inherit;min-width:inherit;max-width:inherit;margin:0;padding:0;font-family:inherit;font-size:inherit;text-align:left}.sdk-select .box .selectbox .dropdown .value{position:absolute;inset:40% 25px 0 5px;display:block;margin:0;padding:0;transform:translateY(-30%);font-family:inherit;font-size:inherit;text-overflow:ellipsis;overflow:hidden;white-space:nowrap}.sdk-select .box .selectbox .dropdown .icon{position:absolute;top:50%;right:0;bottom:0;display:flex;flex-direction:row;align-items:center;width:25px;min-width:25px;max-width:25px;transform:translateY(-50%)}.sdk-select .box .selectbox .values{position:absolute;left:0;right:0;width:inherit;min-width:inherit;max-width:inherit;height:unset!important;min-height:-moz-fit-content!important;min-height:fit-content!important;overflow:hidden;z-index:999;background-color:#fff;border:1px solid #BABABA;font-family:inherit;font-size:inherit}.sdk-select .box .selectbox .values *{cursor:pointer}.sdk-select .box .selectbox .values label{padding:5px 10px 5px 5px;display:block;min-width:inherit;max-width:inherit;white-space:nowrap;font-family:inherit;font-size:inherit}.sdk-select .box .selectbox .values label .icon{display:inline-flex;vertical-align:middle;font-size:1.3em}.sdk-select .box .selectbox .values label .icon.left{margin-right:10px}.sdk-select .box .selectbox .values label .icon.right{margin-left:10px}.sdk-select .box .selectbox .values label .value{position:relative;display:inline-flex;vertical-align:middle;font-family:inherit;font-size:inherit;width:inherit;min-width:inherit;max-width:inherit}.sdk-select .box .selectbox .values label .value .value-text{font-family:inherit;font-size:inherit;text-overflow:ellipsis;overflow:hidden;white-space:nowrap}.sdk-select .box .selectbox .values label.selected{color:var(--selected-color, rgb(25, 100, 141));background-color:var(--selected-background, rgb(225, 245, 255))}.sdk-select .box .selectbox .values label:hover{background-color:var(--hover-color, rgb(240, 240, 240))}\n"] }]
        }], propDecorators: { label: [{
                type: Input
            }], labelPosition: [{
                type: Input
            }], labelStyle: [{
                type: Input
            }], options: [{
                type: Input
            }], optionStyle: [{
                type: Input
            }], noValueLabel: [{
                type: Input
            }], noValueDisabled: [{
                type: Input
            }], displayValue: [{
                type: Input
            }], multiSelect: [{
                type: Input
            }], multiValues: [{
                type: Input
            }], selectedOptions: [{
                type: Input
            }], hoverColor: [{
                type: Input
            }], selectedColor: [{
                type: Input
            }], selectedBackground: [{
                type: Input
            }], selectChangeEvent: [{
                type: Output
            }] } });

class SDKSelectModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.1.8", ngImport: i0, type: SDKSelectModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.1.8", ngImport: i0, type: SDKSelectModule, declarations: [SDKSelectComponent], imports: [CommonModule], exports: [SDKSelectComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.1.8", ngImport: i0, type: SDKSelectModule, imports: [CommonModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.1.8", ngImport: i0, type: SDKSelectModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        SDKSelectComponent
                    ],
                    imports: [
                        CommonModule
                    ],
                    exports: [
                        SDKSelectComponent
                    ],
                    schemas: [
                        NO_ERRORS_SCHEMA
                    ]
                }]
        }] });

/*
 * Public API Surface of sdk-loading
 */

/**
 * Generated bundle index. Do not edit.
 */

export { SDKSelectComponent, SDKSelectModule };
//# sourceMappingURL=sdk-select.mjs.map
